### ----------------------------------------------------------------------
### | Copyright  Unpublished, Rational Software Corporation. All Rights  |
### | Reserved.  This software contains proprietary and confidential     |
### | information of Rational and its suppliers.  Use, disclosure or     |
### | reproduction is prohibited without the prior express written       |
### | consent of Rational Software Corporation.                          |
### ----------------------------------------------------------------------

package ClearCase::CurrentVersion;

use strict;
require Win32::TieRegistry if $ =~ /^(MS(DOS|Win32)|Windows_NT)/;

my $CC_CURR_VER_RGY_KEY = 'LMachine\\Software\\Atria\\ClearCase\\CurrentVersion';
my $CC_ProductHome_NAME = 'ProductHome';
my $CC_RGY_SERVER_NAME = "AtriaRegy";
my $CC_InteropRegion_NAME = "InteropRegion";
my $CC_Region_NAME =  "Region";
my $CC_ClearCaseMajorVersion_NAME = "ClearCaseMajorVersion";
my $CC_LicenseHost_NAME =  "LicenseHost";
my $CC_SmtpServerHost_NAME = "SmtpServerHost";

my $CC_UNIX_ProductHome = "/opt/rational/clearcase";

my $KEY_READ = 'KEY_READ';
my $KEY_WRITE = 'KEY_WRITE';

sub SetProductHomeEV {

    my $jam_producthome = shift;
    if ($ENV{CLEARCASEHOME} =~ /^\s*$/) {
	if ($ENV{ATRIAHOME} !~ /^\s*$/) {
	    $ENV{CLEARCASEHOME} = $ENV{ATRIAHOME};
	} else {
	    if ($ =~ /^(MS(DOS|Win32)|Windows_NT)/) {

            #
            # If CLEARCASEHOME is not already set, get it from ATRIAHOME or registry and
            # set it. Set ATRIAHOME to be same, for compatibility with older scripts.
            #
		$ENV{CLEARCASEHOME} = &GetProductHome;
	    } else {
		$ENV{CLEARCASEHOME} = $CC_UNIX_ProductHome;
	    }
	}
    }
    
    $ENV{CLEARCASEHOME} = $jam_producthome if $jam_producthome;
    
    # set ATRIAHOME for compatibility with older scripts that haven't been
    # converted to use CLEARCASEHOME.

    $ENV{ATRIAHOME} = $ENV{CLEARCASEHOME};
    return $ENV{CLEARCASEHOME};

}

#
# TBD:
# None of the subs below are yet Unix - safe.  
# To get ClearCaseProductHome on Unix, use SetProductHomeEV
#

sub CurrentVersionKey {
    my $access = shift;
    my $Key = Win32::TieRegistry->new($CC_CURR_VER_RGY_KEY,
				      {Access=>$access}) 
	or die 
	    "Can't open ClearCase product version registry key $CC_CURR_VER_RGY_KEY $access\t" 
    . $^E;
    return $Key;
};


sub GetCCValue {
    my $Name = shift;
    my $Key = &CurrentVersionKey($KEY_READ);
    my ($Value,$Type) = $Key->GetValue($Name) 
	or die 
	    "Can't read key name $Name\t" 
		. $^E;
    return $Value;
}

sub GetRgyServer {
    return GetCCValue($CC_RGY_SERVER_NAME);
}

sub GetProductHome{
    return GetCCValue($CC_ProductHome_NAME);
}

sub GetInteropRegion {
    return GetCCValue($CC_InteropRegion_NAME);
}

sub GetRegion {
    return GetCCValue($CC_Region_NAME);
}

sub GetMajorVersion {
    return GetCCValue($CC_ClearCaseMajorVersion_NAME);
}

sub GetLicenseHost {
    return GetCCValue($CC_LicenseHost_NAME);
}

sub GetSmtpServerHost {
    return GetCCValue($CC_SmtpServerHost_NAME);
}

sub SetCCValue {
    my $Name = shift;
    my $Value = shift;
    my $Key = &CurrentVersionKey($KEY_WRITE);
    return $Key->SetValue($Name,$Value);
}

sub SetRgyServer {
    my $Value = shift;
    return SetCCValue($CC_RGY_SERVER_NAME,$Value);
}

sub SetRegion {
    my $Value = shift;
    return SetCCValue($CC_Region_NAME,$Value);
}
